# pykinect-recorder

The pykinect-recorder is an educational/industrial library that provides sensor recording (including audio), playback, and computer vision soultions through a python wrapper of the Azure Kinect Sensor SDK.

## Installation

### Prerequisites

[Azure Kinect SDK](https://github.com/microsoft/Azure-Kinect-Sensor-SDK/blob/develop/docs/usage.md)

#### Windows

```bash
pip install pykinect-recorder

pykinect
```

## Features

ML Solutions: native, mediapipe, torchvision